@@ -143,6 +143,9 @@ get_cr_yaml <- function(x){
       is.readable(x),
       grepl("\\.ya?ml$", x, ignore.case = TRUE)
     )
+  } else if(is.gar_Build(x)){
+    # an existing build
+    return(x)
   } else {
     stop("Yaml is not class(yaml) or a filepath - class:", class(x))
   }
@@ -179,7 +182,7 @@ get_cr_yaml <- function(x){
 #' cr_build_write(build)
 #' }
 cr_build_write <- function(x, file = "cloudbuild.yaml"){
-  myMessage("Writing to ", file, level = 3)
+  myMessage("Writing to", file, level = 3)
   UseMethod("cr_build_write", x)
 }
 
@@ -197,6 +200,7 @@ cr_build_write.gar_Build <- function(x, file = "cloudbuild.yaml"){
     artifacts = x$artifacts
   ))
   cr_build_write.cr_yaml(o, file)
+  file
 }
 
 #' @export
@@ -205,6 +209,6 @@ cr_build_write.cr_yaml <- function(x, file = "cloudbuild.yaml"){
   o <- write_yaml(x, file = file, indent.mapping.sequence = TRUE)
   write(paste("#Generated by googleCloudRunner::cr_build_write at", Sys.time()),
         file = file, append = TRUE)
-  o
+  file
 }
 
